@@ -24,30 +24,9 @@
 ##' }
 ##' @examples
 ##'
-##' # Example in context:
+##' # Example 1 - mnist data
 ##'
-##' \donttest{
-##' download_mnist("mnist.RData") # only need to download once
-##' load("mnist.RData") # loads objects train_set, truth, test_set and test_truth
-##'
-##' net <- network( dims = c(784,16,16,10),
-##'                 activ=list(ReLU(),ReLU(),softmax()))
-##'
-##' netwts <- train(dat=train_set,
-##'                 truth=truth,
-##'                 net=net,
-##'                 eps=0.001,
-##'                 tol=0.8, # normally would use a higher tol here e.g. 0.95
-##'                 loss=multinomial(),
-##'                 batchsize=100)
-##'
-##' pred <- NNpredict(  net=net,
-##'                     param=netwts$opt,
-##'                     newdata=test_set,
-##'                     newtruth=test_truth,
-##'                     record=TRUE,
-##'                     plot=TRUE)
-##' }
+##' # See example at mnist repository under user bentaylor1 on githib
 ##'
 ##' # Example 2
 ##'
@@ -126,7 +105,7 @@ NNpredict <- function(net,param,newdata,newtruth=NULL,freq=1000,record=FALSE,plo
         plot(err)
         lines(lowess(err),col="red",main="")
 
-        browser()
+        # browser()
 
         plot(jitter(tru),jitter(prednos),main="Prediction Vs Truth ABS")
         plot(jitter(tru),jitter(prednos_MC),main="Prediction Vs Truth MC")
